@@ -1,25 +1,13 @@
-/* This file is part of KDevelop
-    Copyright 2006 Hamish Rodda <rodda@kde.org>
-    Copyright 2008 Niko Sams <niko.sams@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "lexertest.h"
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 #include "parsesession.h"
 #include "phplexer.h"
@@ -471,7 +459,7 @@ void LexerTest::testReturnTypeHints()
     COMPARE_TOKEN(ts, 5, Parser::Token_RPAREN, 1, 11, 1, 11);
     COMPARE_TOKEN(ts, 6, Parser::Token_COLON, 1, 12, 1, 12);
     COMPARE_TOKEN(ts, 7, Parser::Token_WHITESPACE, 1, 13, 1, 13);
-    COMPARE_TOKEN(ts, 8, Parser::Token_STRING_TYPE, 1, 14, 1, 19);
+    COMPARE_TOKEN(ts, 8, Parser::Token_STRING, 1, 14, 1, 19);
     COMPARE_TOKEN(ts, 9, Parser::Token_WHITESPACE, 1, 20, 1, 20);
     COMPARE_TOKEN(ts, 10, Parser::Token_LBRACE, 1, 21, 1, 21);
     COMPARE_TOKEN(ts, 11, Parser::Token_RBRACE, 1, 22, 1, 22);
